module.exports = defineTest({
	description: 'side-effects when mutating destructured variables should not be ignored'
});
